@@ -7,12 +7,12 @@
 ##' @param n numeric; the number of posterior samples to return.
 ##' @param seed numeric; a random seed for the simulations.
 ##' @param scale character;
-##' @param freq logical; `TRUE` to return the frequentist covariance matrix of
-##'   the parameter estimators, `FALSE` to return the Bayesian posterior
+##' @param freq logical; `TRUE` to use the frequentist covariance matrix of
+##'   the parameter estimators, `FALSE` to use the Bayesian posterior
 ##'   covariance matrix of the parameters.
 ##' @param unconditional logical; if `TRUE` (and `freq == FALSE`) then the
 ##'   Bayesian smoothing parameter uncertainty corrected covariance matrix is
-##'   returned, if available.
+##'   used, if available.
 ##' @param weights numeric; a vector of prior weights. If `newdata` is null
 ##'   then defaults to `object[["prior.weights"]]`, otherwise a vector of ones.
 ##' @param ncores number of cores for generating random variables from a
@@ -123,6 +123,7 @@
 
     V <- get_vcov(model, frequentist = freq, unconditional = unconditional)
     Rbeta <- rmvn(n = n, mu = coef(model), sigma = V, ncores = ncores)
+    ## don't need to pass freq, unconditional here as that is done for V
     Xp <- predict(model, newdata = newdata, type = "lpmatrix", ...)
     sims <- Xp %*% t(Rbeta)
 
@@ -169,9 +170,23 @@
 ##' op <- options(cli.unicode = FALSE)
 ##' }
 ##' dat <- gamSim(1, n = 1000, dist = "normal", scale = 2)
-##' m1 <- gam(y ~ s(x0) + s(x1) + s(x2) + s(x3), data = dat, method = "REML")
+##' m <- gam(y ~ s(x0) + s(x1) + s(x2) + s(x3), data = dat, method = "REML")
 ##'
-##' predicted_samples(m1, n = 5, seed = 42)
+##' predicted_samples(m, n = 5, seed = 42)
+##'
+##' ## Can pass arguments to predict.gam()
+##' newd <- data.frame(x0 = runif(10), x1 = runif(10), x2 = runif(10),
+##'                    x3 = runif(10))
+##'
+##' ## Exclude s(x2)
+##' predicted_samples(m, n = 5, newd, exclude = "s(x2)", seed = 25)
+##'
+##' ## Exclude s(x1)
+##' predicted_samples(m, n = 5, newd, exclude = "s(x1)", seed = 25)
+##'
+##' ## Select which terms --- result same as previous
+##' predicted_samples(m, n = 5, newd, seed = 25,
+##'                   terms = c("s(x0)", "s(x2)", "s(x3)"))
 ##' \dontshow{options(op)}
 `predicted_samples` <- function(model, ...) {
     UseMethod("predicted_samples")
@@ -188,10 +203,9 @@
 ##' @importFrom tibble as_data_frame add_column
 ##' @importFrom tidyr gather
 `predicted_samples.gam` <- function(model, n = 1, newdata = NULL, seed = NULL,
-                                    freq = FALSE, unconditional = FALSE,
                                     weights = NULL, ...) {
-    sims <- simulate(model, nsim = n, seed = seed, newdata = newdata, freq = freq,
-                     unconditional = unconditional, weights = weights)
+    sims <- simulate(model, nsim = n, seed = seed, newdata = newdata,
+                     weights = weights, ...)
     RNGstate <- attr(sims, "seed")
     colnames(sims) <- paste0(".V", seq_len(NCOL(sims)))
     sims <- as_tibble(sims)
